/*
    anjuta_info.h
    Copyright (C) 2000  Kh. Naba Kumar Singh

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _ANJUTA_INFO_H_
#define _ANJUTA_INFO_H_

gboolean anjuta_info_show_file (const gchar * path,	gint height, gint width);

gboolean anjuta_info_show_command (const gchar * command_line,
								   gint height, gint width);

gboolean anjuta_info_show_string (const gchar * s, gint height, gint width);

gboolean anjuta_info_show_filestream (FILE * f, gint height, gint width);

gboolean anjuta_info_show_fd (int file_descriptor, gint height, gint width);

void anjuta_info_show_list (GList* list, gint height, gint width);

#endif
